pub enum ErrorType {
Show 22 variants
BadAuthCode,
BadFlag,
BadParameter,
NoValueAvailable,
ExceptionThrown,
InsufficientBufferSpace,
StringConversionError,
InternalError,
InvalidInput,
InvalidObject,
InvalidObjectState,
InvalidVerifier,
InvalidKeyLength,
KeyNotSet,
NotImplemented,
NullPointer,
OutOfMemory,
SystemError,
UnknownError,
ConversionError,
TlsError,
HttpError,
}Expand description
Possible error categories
Variants
BadAuthCode
A provided authentication code was incorrect
BadFlag
A bad flag was passed to the library
BadParameter
An invalid parameter was provided to the library
NoValueAvailable
No value available
ExceptionThrown
An exception was thrown while processing this request
InsufficientBufferSpace
There was insufficient buffer space to write the output
StringConversionError
Converting a string to UTF8 failed
InternalError
An internal error occurred (this is a bug in the library)
InvalidInput
Something about the input was invalid
InvalidObject
An invalid object was provided to the library
InvalidObjectState
An object was invoked in a way that is invalid for its current state
InvalidVerifier
A verifier was incorrect
InvalidKeyLength
An key of invalid length was provided
KeyNotSet
An object was invoked without the key being set
NotImplemented
Some functionality is not implemented in the current library version
NullPointer
A null pointer was incorrectly provided
OutOfMemory
Memory exhaustion
SystemError
An error occurred while invoking a system API
UnknownError
Some unknown error occurred
ConversionError
An error occured while converting data to C
TlsError
An error occurred in TLS
HttpError
An error occurred during an HTTP transaction